Index: src/wp-includes/comment.php
===================================================================
--- src/wp-includes/comment.php	(revision 38024)
+++ src/wp-includes/comment.php	(working copy)
@@ -51,15 +51,27 @@
 		$num_links = preg_match_all( '/<a [^>]*href/i', $comment, $out );
 
 		/**
 		 * Filters the maximum number of links allowed in a comment.
 		 *
 		 * @since 3.0.0
 		 *
 		 * @param int    $num_links The number of links allowed.
 		 * @param string $url       Comment author's URL. Included in allowed links total.
 		 */
 		$num_links = apply_filters( 'comment_max_links_url', $num_links, $url );
 
+		/**
+		 * Filters the number of links found in the comment.
+		 *
+		 * @since 4.7.0
+		 *
+		 * @param int    $num_links         The number of links found in the comment.
+		 * @param string $comment           Comment author's URL. Included in allowed links total.
+		 * @param array  $function_args     All the args passed to the function ( $author, $email, $url, $comment, $user_ip, $user_agent, $comment_type )
+		 */
+		$num_links = apply_filters( 'links_found_in_comment', $num_links, $comment, func_get_args() );
+
+
 		/*
 		 * If the number of links in the comment exceeds the allowed amount,
 		 * fail the check by returning false.
@@ -51,15 +51,27 @@
 
 		/**
-		 * Filters the maximum number of links allowed in a comment.
+		 * Filters the number of links found in the comment.
 		 *
 		 * @since 3.0.0
@@ -51,15 +51,27 @@
 		 * @since 3.0.0
 		 *
-		 * @param int    $num_links The number of links allowed.
+		 * @param int    $num_links The number of links found in the comment.
 		 * @param string $url       Comment author's URL. Included in allowed links total.
 		 */